Heading

Trait Heading 

pub trait Heading: Path {
    // Required method
    fn heading_at(&self, s: Self::Scalar) -> Result<Self::Scalar, Self::Error>;
}
Query the planar heading angle at any point along a path.

Heading is meaningful only for 2D paths, where it represents the angle (in radians, counter-clockwise from the positive x-axis) of the tangent.

Required Methods

fn heading_at(&self, s: Self::Scalar) -> Result<Self::Scalar, Self::Error>

Planar heading angle (radians) at arc-length s.

Returns an error when s is outside the domain or the heading is undefined at this point.

Implementors